# qrwifi

Display a QR code for your wifi in the terminal.

Currently only supports macOS. Create an issue if you want me to support your OS.

## Installation

```
pip install qrwifi
```

## Usage

```
qrwifi
```